<a href="{% url 'bee_django_crm:preuser_list' %}?level=1">用户管理</a> |

{% if perms.bee_django_crm.view_crm_preuser_contract %}
    <a href="{% url 'bee_django_crm:preuser_contract_list' 0 %}">用户合同管理</a> |
{% endif %}
{% if perms.bee_django_crm.view_crm_preuser_fee %}
    <a href="{% url 'bee_django_crm:preuser_fee_list' 0 %}">用户缴费管理</a> |
{% endif %}
{% if perms.bee_django_crm.view_crm_application %}
    <a href="{% url 'bee_django_crm:application_question_list' %}">申请表管理</a> |
{% endif %}
{% if perms.bee_django_crm.view_crm_source %}
    <a href="{% url 'bee_django_crm:source_list' %}">渠道管理</a> |
{% endif %}
{% if perms.bee_django_crm.view_crm_contract %}
    <a href="{% url 'bee_django_crm:contract_list' %}">合同模版管理</a> |
{% endif %}
{% if perms.bee_django_crm.view_crm_contract %}
    <a href="{% url 'bee_django_crm:regcode_check' %}">卡密验证</a> |
{% endif %}
<a href="http://note.youdao.com/noteshare?id=21a744e19bdf4fcc3936f94e8d542cac" target="_blank">帮助文档</a> |
{#    <a href="{% url 'bee_django_crm:poster_list' %}">海报管理</a> |#}