# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2019-04-22 00:28
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0016_auto_20190111_1554'),
    ]

    operations = [
        migrations.CreateModel(
            name='RegCode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reg_code', models.CharField(max_length=50, verbose_name=b'\xe6\xb3\xa8\xe5\x86\x8c\xe5\x8d\xa1\xe5\xaf\x86')),
                ('reg_name', models.CharField(max_length=180, verbose_name=b'\xe6\xb3\xa8\xe5\x86\x8c\xe5\x8d\xa1\xe5\x8f\xb7')),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]
