# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-06-22 08:03
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0003_auto_20180608_1917'),
    ]

    operations = [
        migrations.AddField(
            model_name='preuser',
            name='referral_user1',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_crm_referral_user1', to=settings.AUTH_USER_MODEL, verbose_name=b'\xe6\x8e\xa8\xe8\x8d\x90\xe4\xba\xba'),
        ),
        migrations.AddField(
            model_name='preuser',
            name='referral_user2',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_crm_referral_user2', to=settings.AUTH_USER_MODEL, verbose_name=b'\xe6\x8e\xa5\xe5\xbc\x95\xe4\xba\xba'),
        ),
        migrations.AlterField(
            model_name='preuser',
            name='referral_user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='bee_crm_referral_user', to=settings.AUTH_USER_MODEL, verbose_name=b'\xe5\x8e\x9f\xe6\x8e\xa8\xe8\x8d\x90\xe4\xba\xba'),
        ),
    ]
