{% load bee_django_crm_filter %}
<div class="text-center"><h3>已缴费</h3></div>
<table class="table">
    <thead>
    <tr>
        <th></th>
        <th>学号</th>
        <th>姓名</th>
        <th>电话</th>
        <th>报名来源</th>
        <th>推荐人</th>
        <th>省</th>
        <th>市</th>
        <th>合同</th>
        <th></th>

    </tr>
    </thead>
    <tbody>
    {% for preUser in preuser_list %}
        <tr>
            <td>{{ forloop.counter }} </td>
            <td>
                {% if preUser.get_user_username %}
                    <a href="{{ preUser.userprofile.user.get_user_search_link }}">{{ preUser.get_user_username }}</a>
                {% endif %}

            </td>
            <td>
                <a href="{% url 'bee_django_crm:preuser_detail' preUser.id %}?admin=1">{{ preUser.name }}</a>
                {% if preUser.pay_status == 2 %}
                    <span style="color: red">（{{ preUser.get_pay_status }}）</span>
                {% endif %}
            </td>
            <td>{{ preUser.mobile }}</td>
            <td>{{ preUser.source|default:"无" }}</td>
            <td>{{ preUser|get_referral_user_name|default:"无" }}</td>
            <td>{{ preUser.province|default:"无" }}</td>
            <td>{{ preUser.city|default:"无" }}</td>
            <td><a href="{% url 'bee_django_crm:preuser_contract_list' preUser.id %}">详情</a></td>
            <td>

            </td>


        </tr>


    {% endfor %}
    </tbody>
</table>
