# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-22 09:36
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('bee_django_crm', '0005_auto_20180708_1503'),
    ]

    operations = [
        migrations.CreateModel(
            name='PreUserFee',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('price', models.FloatField(verbose_name=b'\xe5\xae\x9e\xe6\x94\xb6\xe9\x87\x91\xe9\xa2\x9d')),
                ('paid_at', models.DateTimeField(verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe6\x97\xa5\xe6\x9c\x9f')),
                ('study_at', models.DateTimeField(blank=True, null=True, verbose_name=b'\xe5\xbc\x80\xe8\xaf\xbe\xe6\x97\xa5\xe6\x9c\x9f')),
                ('pay_status', models.IntegerField(choices=[(1, b'\xe5\x85\xa8\xe6\xac\xbe'), (2, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xa4\xb4\xe6\xac\xbe'), (3, b'\xe5\x88\x86\xe6\x9c\x9f\xe4\xb8\xad'), (4, b'\xe5\x88\x86\xe6\x9c\x9f\xe5\xb0\xbe\xe6\xac\xbe')], default=1, verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe7\xb1\xbb\xe5\x9e\x8b')),
                ('is_checked', models.BooleanField(default=False, verbose_name=b'\xe5\xae\xa1\xe6\xa0\xb8')),
                ('checked_at', models.DateTimeField(null=True)),
                ('after_checked_at', models.DateTimeField(null=True)),
                ('info', models.TextField(blank=True, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('checked_by', models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
                ('preuser', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.PreUser')),
            ],
            options={
                'ordering': ['-paid_at', '-created_at'],
                'db_table': 'bee_django_crm_preuser_fee',
                'permissions': (('view_crm_preuser_fee', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u7f34\u8d39'),),
            },
        ),
        migrations.AlterModelOptions(
            name='preusercontract',
            options={'ordering': ['-created_at'], 'permissions': (('view_crm_preuser_contract', '\u53ef\u4ee5\u67e5\u770b\u7528\u6237\u5408\u540c'),)},
        ),
        migrations.AddField(
            model_name='contract',
            name='agreement',
            field=models.TextField(null=True, verbose_name=b'\xe9\xa1\xbb\xe7\x9f\xa5'),
        ),
        migrations.AddField(
            model_name='preusercontract',
            name='is_migrate',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='preusercontract',
            name='is_user_agree',
            field=models.BooleanField(default=False, verbose_name=b'\xe7\x94\xa8\xe6\x88\xb7\xe6\x98\xaf\xe5\x90\xa6\xe5\x90\x8c\xe6\x84\x8f'),
        ),
        migrations.AlterField(
            model_name='preusercontract',
            name='paid_at',
            field=models.DateTimeField(null=True, verbose_name=b'\xe7\xbc\xb4\xe8\xb4\xb9\xe6\x97\xa5\xe6\x9c\x9f'),
        ),
        migrations.AlterField(
            model_name='preusercontract',
            name='price',
            field=models.FloatField(verbose_name=b'\xe5\xba\x94\xe6\x94\xb6\xe9\x87\x91\xe9\xa2\x9d'),
        ),
        migrations.AddField(
            model_name='preuserfee',
            name='preuser_contract',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='bee_django_crm.PreUserContract'),
        ),
    ]
