# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-08-23 10:51
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_crm', '0009_applicationquestion_is_required'),
    ]

    operations = [
        migrations.AlterField(
            model_name='applicationquestion',
            name='is_required',
            field=models.BooleanField(default=False, help_text=b'\xe5\x8f\xaa\xe5\xaf\xb9\xe8\xbe\x93\xe5\x85\xa5\xe6\xa1\x86\xe5\x92\x8c\xe5\x8d\x95\xe9\x80\x89\xe6\x9c\x89\xe6\x95\x88', verbose_name=b'\xe6\x98\xaf\xe5\x90\xa6\xe5\xbf\x85\xe5\xa1\xab'),
        ),
    ]
