{% extends "bee_django_crm/base.html" %}
{% load static %}
{% load bootstrap3 %}
{% block styles %}
    <style>
        body {
            background-color: #1A3440;
        }

        .app_title {
            background-color: #6A90A1;
            padding: 10px;
            color: #ffffff;
        }

        .app_body {
            background-color: #ffffff;
            padding: 20px;
        }
    </style>
{% endblock %}

{% block content %}
    <div class="app_title text-center"><h4>申请表</h4></div>
    <div class="app_body">
        <form method="post">
                {% csrf_token %}

                {% bootstrap_form form %}
            <div class="text-center">{% bootstrap_button '提交' %}</div>
        </form>
    </div>
{% endblock %}


{% block scripts %}
    <script>
        $(document).ready(function () {
            //时间
            {#            $.datetimepicker.setLocale('ch');#}
            {#            var $birthday = $("#id_birthday");#}
            {#            $birthday.datetimepicker({#}
            {#                format: 'Y-m-d',#}
            {#                timepicker: false,#}
            {#                scrollMonth: false,#}
            {#                scrollTime: false,#}
            {#                scrollInput: false#}
            {#            });#}

        });

    </script>
{% endblock %}